<?php

$themename = "Sonar";
$shortname = "sonar";
$option_group = $shortname.'_theme_option_group';
$option_name = $shortname.'_theme_options';

// Load stylesheet and jscript
add_action('admin_init', 'sonar_add_init');

function sonar_add_init() {

    $file_dir = get_template_directory_uri();
	wp_enqueue_style("sonarOptCss", $file_dir."/admin/sonar-options.css");
	wp_enqueue_script("sonarOptScript", $file_dir."/admin/sonar-options.js");
	wp_enqueue_script('dashboard');
	wp_enqueue_script('sonarjscolor', $file_dir.'/js/jscolor/jscolor.js');
}

// Create custom settings menu
add_action('admin_menu', 'sonar_create_menu');

function sonar_create_menu() {

	global $themename;
	//create new top-level menu
	add_theme_page( __( $themename.' sonar Options' ), __( 'sonar Options' ), 'edit_theme_options', basename(__FILE__), 'sonar_settings_page' );
}

// Register settings
add_action( 'admin_init', 'register_settings' );

function register_settings() {

   global $themename, $shortname, $version, $sonar_options, $option_group, $option_name;
	//register our settings
	register_setting( $option_group, $option_name, 'sonar_theme_options_validate');
}

// Create theme options
global $sonar_options;

$sonar_options = array (
	// ***************************  General Appearance Options  ***********************************
	array("name" => __( "",'sonar'), "id" =>"", "type" => "header",
			"desc" => __( "",'sonar'),
			"std" => ""),
		
	array("name" => __('<font size=4 color=#464646>General Appearance</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Settings that change the look of your content.</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),

	array(  'name' => __('Outside Background','sonar'), 'id' => 'sonar_body_bgcolor', 'type' => 'ctext',
			"desc" => __( 'Outside background color around page. Using <em>Appearance->Background</em> will override this setting, or allow a background image instead.','sonar'),
			"std" => '#53A4E6'),
			
	array("name" => __( 'Remove Default Backgound Image','sonar'), 'id' => 'sonar_remove_default_background', 'type' => 'checkbox',
			"desc" => __( 'Removes the default background image from around page. Using <em>Appearance->Background</em> will override this setting.','sonar')),

	array(  'name' => __('Standard Link','sonar'), 'id' => 'sonar_link_color', 'type' => 'ctext',
			"desc" => __( 'Color for most links.','sonar'),
			'std' => '#044085'),
			
    array(  'name' => __('Standard Link Visited','sonar'), 'id' => 'sonar_link_visited_color', 'type' => 'ctext',
			"desc" => __( 'Color for links that have been visited.','sonar'),
			'std' => '#0773F0'),
			
    array(  'name' => __('Standard Link Hover','sonar'), 'id' => 'sonar_link_hover_color', 'type' => 'ctext',
			"desc" => __( 'Color for links when hovered over.','sonar'),
			'std' => '#0662CC'),
	
	array(  "name" => __( 'Content Title Color','sonar'), 'id' => 'sonar_content_title_link_color', 'type' => 'ctext',
			"desc" => __( 'Color for the content title links.','sonar'),
			'std' => '#000000'),
			
    array(  "name" => __( 'Content Title Color on Hover','sonar'), 'id' => 'sonar_content_title_hover_color', 'type' => 'ctext',
			"desc" => __( 'Color for the content title links when hovered over.','sonar'),
			'std' => '#0773F0;'),

	array ( 'name' => __('Content Fonts','sonar'), 'id' => 'sonar_content_area_font', 'type' => 'select',
			'desc' => __('Font used for the content','sonar'),
			'std' => 'Arial, sans-serif',
			'value' => array( __('Arial, sans-serif','sonar'),
			'Bitstream Charter, serif', 'Courier New, mono', 'Verdana, sans-serif', 'Tahoma, sans-serif',
			'Arial Black, sans-serif', 'Avant Garde, sans-serif','Helvetica Neue, sans' ,
			'Impact, sans-serif', 'Trebuchet, sans-serif', 'Century Gothic, sans-serif',
			'Lucida Grande, sans-serif', 'Univers, sans-serif',
			'Times New Roman, serif', 'Georgia, serif', 'Palatino, serif',
			'Bookman, serif', 'Garamond, serif',
			'Andale Mono, mono', 'Comic Sans MS, sans-serif')),
		 		
	array(  "name" => __( 'Content List Bullet','sonar'), 'id' => 'sonar_content_bullet_color', 'type' => 'select',
			"desc" => __( 'Bullet used for Unorderd Lists in content area.','sonar'),
			'std' => 'default',
			'value' => array( __('default','sonar'), __('circle','sonar'), 'disc', 'square', 'circle-black', 'circle-blue', 'circle-white', 'star-black', 'star-blue', 'star-yellow', 'square-black', 'square-blue',
						'square-white', 'check-black', 'check-blue', 'check-white', 'heart-red', 'paw-print', 'radiation-black')),
	
	array(  "name" => __( 'Remove Post Calendar','sonar'), 'id' => 'sonar_remove_post_calendar', 'type' => 'checkbox',
			"desc" => __( 'Removes the calendar next to post titles.','sonar')),
	
	array(  "name" => __( 'Calendar Border Color','sonar'), 'id' => 'sonar_calendar_border_color', 'type' => 'ctext',
			"desc" => __( 'Color of the border around the calendar.','sonar'),
			'std' => '#555555'),
			
	array(  "name" => __( 'Calendar Month BG Color','sonar'), 'id' => 'sonar_calendar_month_BG_color', 'type' => 'ctext',
			"desc" => __( 'Color of the calendar month background.','sonar'),
			'std' => '#53A4E6'),
			
	array("name" => __( "Calendar Month Text Color",'sonar'), "id" => "sonar_calendar_month_text_color", "type" => "ctext",
			"desc" => __( "Color of the calendar text displaying the month. ",'sonar'),
			"std" => "#FFFFFF"),
			
	array(  "name" => __( 'Calendar Day BG Color','sonar'), 'id' => 'sonar_calendar_day_BG_color', 'type' => 'ctext',
			"desc" => __( 'Color of the calendar day background.','sonar'),
			'std' => '#F6F6F6'),
			
	array("name" => __( "Calendar Day Text Color",'sonar'), "id" => "sonar_calendar_day_text_color", "type" => "ctext",
			"desc" => __( "Color of the calendar text displaying the day. ",'sonar'),
			"std" => "#000000"),
			
	array(  "name" => __( 'Aside Post Background','sonar'), 'id' => 'sonar_aside_post_BG_color', 'type' => 'ctext',
			"desc" => __( 'Color of the aside post background.','sonar'),
			'std' => '#D2E9FA'),
			
	array(  "name" => __( 'Sicky Post Background','sonar'), 'id' => 'sonar_sticky_post_BG_color', 'type' => 'ctext',
			"desc" => __( 'Color of the sicky post background.','sonar'),
			'std' => '#D2E9FA'),
			
	array("type" => "close"),
	
	// ************************************  Header Options  *********************************************
	array("name" => __('<font size=4 color=#464646>Header Options</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Settings that change the look of your header and menus.</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),
	
    array("name" => __( 'Menu Bar','sonar'), "id" => "sonar_menubar_color", "type" => "ctext",
			"desc" => __( 'Color of the main menu bar ( If you want to go back to the default Transparent Menu Background use #292929)','sonar'),
			"std" => '#292929'),
			
    array("name" => __( "Menu Bar hover BG",'sonar'), "id" => "sonar_menubar_hoverbg_color", "type" => "ctext",
			"desc" => __( "Color of the menu item background when hovering over item.",'sonar'),
			"std" => "#333333"),
			
	array("name" => __( "Menu Bar dropdown BG",'sonar'), "id" => "sonar_menubar_dropbg_color", "type" => "ctext",
			"desc" => __( "Color of the menu drop down background.",'sonar'),
			"std" => "#444444"),
			
    array("name" => __( "Menu Bar text",'sonar'), "id" => "sonar_menubar_text_color", "type" => "ctext",
			"desc" => __( "Color of the main menu bar text item when not hovering",'sonar'),
			"std" => "#AAAAAA"),
			
    array("name" => __( "Menu Bar text hover",'sonar'), "id" => "sonar_menubar_hover_color", "type" => "ctext",
			"desc" => __( "Color of the main menu bar text item when hovering",'sonar'),
			"std" => "#FFFFFF"),
			
    array("name" => __( "Menu Bar current page",'sonar'), "id" => 'sonar_menubar_curpage_color', "type" => "ctext",
			"desc" => __( "Color of the main menu bar text item for currently displayed page",'sonar'),
			"std" => "#53A4E6"),
			
    array("name" => __( "Normal Menu Text",'sonar'), "id" => "sonar_normal_menu_text", "type" => "checkbox",
			"desc" => __( "Check to use normal font style for menu text instead of bold.",'sonar')),

	array( "name" => __( 'Menu BG Image Effect','sonar'), 'id' => 'sonar_menu_remove_fade', 'type' => 'select',
			"desc" => __( 'The Background image for the menu bar. None, Fade, or Glass.','sonar'),
			'std' => 'None',
			'value' => array( 'None', 'Fade', 'Glass')),	
			
	array( "name" => __( 'Disable Superfish Menu Effects','sonar'), 'id' => 'sonar_remove_superfish', 'type' => 'checkbox',
			"desc" => __( 'Removes the arrows next to your menu items.','sonar')),
			
	array( "name" => __( 'Superfish Colors','sonar'), 'id' => 'sonar_superfish_arrow_color', 'type' => 'select',
			"desc" => __( 'Color of the Superfish arrows on the menu bar.','sonar'),
			'std' => 'White',
			'value' => array( 'White', 'Silver', 'Blue', 'Red', 'Black')),
	
	array( "name" => __( 'Site Title','sonar'), 'id' => 'sonar_title_color', 'type' => 'ctext',
			"desc" => __( "Color of the blog's main title in header.",'sonar'),
			'std' => '#FFFFFF'),
	array( "name" => __( 'Site Description','sonar'), 'id' => 'sonar_description_color', 'type' => 'ctext',
			"desc" => __( "Color of the blog's description in header.",'sonar'),
			'std' => '#53A4E6'),
			
	array ( 'name' => __('Title and Description Fonts','sonar'), 'id' => 'sonar_title_description_font', 'type' => 'select',
			'desc' => __('Font used for the title and Description.','sonar'),
			'std' => 'Default-Droid+Serif',
			'value' => array( __('Default-Droid+Serif','sonar'),
			'Tahoma,Arial,Helvetica,sans-serif','Bitstream Charter, serif', 'Arial, sans-serif', 'Verdana, sans-serif', 
			'Arial Black, sans-serif', 'Avant Garde, sans-serif','Helvetica Neue, sans' ,'Courier New, mono',
			'Impact, sans-serif', 'Trebuchet, sans-serif', 'Century Gothic, sans-serif', 'Tahoma, sans-serif',
			'Lucida Grande, sans-serif', 'Univers, sans-serif','Times New Roman, serif', 'Georgia, serif', 'Palatino, serif',
			'Bookman, serif', 'Garamond, serif','Andale Mono, mono', 'Comic Sans MS, sans-serif')),

    array( "name" => __( 'Hide Site Title and Description','sonar'), 'id' => 'sonar_hide_site_title', 'type' => 'checkbox',
			"desc" => __( 'Check to hide display of Site Title and Description.','sonar')),
			
	array( "name" => __( 'Remove Search From Header','sonar'), 'id' => 'sonar_remove_header_search', 'type' => 'checkbox',
			"desc" => __( 'Removes the search bar from header.','sonar')),		

	array("type" => "close"),
	
	// *****************************  Sidebar Options  **********************************
	array("name" => __('<font size=4 color=#464646>Sidebar Options</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Settings that change the look of your sidebar.</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),
			
	array( "name" => __( 'Widget Title Background Color','sonar'), 'id' => 'sonar_widget_title_bgcolor', 'type' => 'ctext',
			"desc" => __( 'This will change the background color of the widget title.','sonar'),
			'std' => '#53A4E6'),
			
	array( "name" => __( 'Widget Title Text Color','sonar'), 'id' => 'sonar_widget_title_txtcolor', 'type' => 'ctext',
			"desc" => __( 'This will change the text color of the widget title.','sonar'),
			'std' => '#FFFFFF'),
			
	array( "name" => __( 'Remove Title BG Gradients','sonar'), 'id' => 'sonar_remove_title_gradients', 'type' => 'checkbox',
			"desc" => __( 'Removes the gradients from the background of the widget menu title.','sonar')),
			
	array( "name" => __( 'widget List Bullet','sonar'), 'id' => 'sonar_widget_bullet_color', 'type' => 'select',
			"desc" => __( 'Bullet used for Unorderd Lists in sidebar area.','sonar'),
			'std' => 'default',
			'value' => array( 'default', 'circle', 'disc', 'square', 'circle-black', 'circle-blue', 'circle-white', 'star-black', 'star-blue', 'star-yellow', 'square-black', 'square-blue',
						'square-white', 'check-black', 'check-blue', 'heart-red', 'paw-print', 'radiation-black')),
						
	array("type" => "close"),
	
	// ************************************  Comment Options  ******************************
	array("name" => __('<font size=4 color=#464646>Comment Options</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Settings that change the look of your comments.</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),
			
	array( "name" => __( 'Avatar Border Color','sonar'), 'id' => 'sonar_avatar_border_color', 'type' => 'ctext',
			"desc" => __( 'Changes the color of the border around avatar image.','sonar'),
			'std' => '#C4C4C4'),
			
	array(  'name' => __('Remove Reply Bubble','sonar'), 'id' => 'sonar_remove_reply_bubble', 'type' => 'checkbox',
			"desc" => __( "Removes the reply bubble in the upper right hand corner of post on blog pages.",'sonar')),
			
	array(  "name" => __( 'Reply Bubble Text','sonar'), 'id' => 'sonar_reply_bubble_text_color', 'type' => 'ctext',
			"desc" => __( 'Color of the reply bubble text.','sonar'),
			'std' => '#53A4E6'),
			
	array(  "name" => __( 'Reply Bubble Hover Text','sonar'), 'id' => 'sonar_reply_bubble_text_hover_color', 'type' => 'ctext',
			"desc" => __( 'Color of the reply bubble text when hovering.','sonar'),
			'std' => '#0773F0'),
			
	array("type" => "close"),
	
	// **********************************  Footer Options  **************************************
	array("name" => __('<font size=4 color=#464646>Footer Options</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Settings that change the look of your footer.</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),
	 
	array( "name" => __( 'Footer Background Color','sonar'), 'id' => 'sonar_footer_color', 'type' => 'ctext', 
			"desc" => __( "Color of the footer background.",'sonar'),
			'std' => '#FFFFFF'),
			
	array( "name" => __( 'Remove sonar Link','sonar'), 'id' => 'sonar_hide_wp_link', 'type' => 'checkbox',
			"desc" => __( 'It is completely optional, but if you like the Theme I would appreciate it if you keep the credit link at the bottom, or else consider making a contribution to help future development of this Theme.','sonar')),
		
	array(  "name" => __( 'Site Copyright','sonar'), 'id' => 'sonar_add_custom_copyright', 'type' => 'text',
			"desc" => __( 'If you enter anything here, the default copyright notice in the footer will be replaced with the text here. It will not
		automatically update from year to year. Use <code>&amp;copy;</code> to display &copy;. You can use other HTML as well.','sonar'),
			'std' => ''),
			
	array( "name" => __( 'Footer HTML','sonar'),
			"desc" => __( '<a href="http://www.w3schools.com/html/html_links.asp" TARGET="_blank"><div class="sonar-help" title="Help with HTML links"></div></a>
					This code will be inserted into the footer area, right after the Footer widgets, but right before the before the Site Copyright. This
					could include extra information, Links, visit counters, etc.','sonar'),
			'id' => 'sonar_footer_opts',
			'type' => 'textarea'),
			
	array("type" => "close"),
	
	// *****************************  Pagination Options  *****************************
	array("name" => __('<font size=4 color=#464646>Pagination</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Numbered post pages and comment pages</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),
			
	array( "name" => __( 'Text Color','sonar'), 'id' => 'sonar_pagination_text_color', 'type' => 'ctext',
			"desc" => __( 'Changes the text color of the text and page numbers.','sonar'),
			'std' => '#FFFFFF'),
			
	array( "name" => __( 'Background Color','sonar'), 'id' => 'sonar_pagination_bg_color', 'type' => 'ctext',
			"desc" => __( 'Changes the Pagination background color.','sonar'),
			'std' => '#888888'),
			
	array( "name" => __( 'Text Color on Hover','sonar'), 'id' => 'sonar_pagination_hover_text_color', 'type' => 'ctext',
			"desc" => __( 'Changes the text color of the text and page numbers when hovered over.','sonar'),
			'std' => '#FFFFFF'),
			
	array( "name" => __( 'BackGround Color on Hover','sonar'), 'id' => 'sonar_pagination_hover_bg_color', 'type' => 'ctext',
			"desc" => __( 'Changes the background color when hovered over.','sonar'),
			'std' => '#53A4E6'),
			
	array( "name" => __( 'Text Color on Current Page','sonar'), 'id' => 'sonar_pagination_current_text_color', 'type' => 'ctext',
			"desc" => __( 'Changes the text color of the text and page numbers on current page.','sonar'),
			'std' => '#FFFFFF'),
			
	array( "name" => __( 'BackGround Color on Current Page','sonar'), 'id' => 'sonar_pagination_current_bg_color', 'type' => 'ctext',
			"desc" => __( 'Changes the background color on current page.','sonar'),
			'std' => '#53A4E6'),
			
	array("type" => "close"),
	
	// *****************************  Advanced Options  ***********************************
	array("name" => __('<font size=4 color=#464646>Advanced Options</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Custom CSS and SEO Plugin Support</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),
	
	array( "name" => __( '! Use SEO Plugin Instead','sonar'), 'id' => 'sonar_hide_metainfo', 'type' => 'checkbox',
			"desc" => __( "Check this box if using an SEO plugin to stop from getting duplicate META tags",'sonar')),
	
	array( "name" => __( 'Disable IE rounded corners','sonar'), 'id' => 'sonar_disable_ie_css3', 'type' => 'checkbox',
			"desc" => __( "Disables rounded corners and shadows in Internet Explorer 8 and latter Versions - ( CSS3 PIE )",'sonar')),
	
	array( "name" => __( 'Custom CSS ','sonar'),
			"desc" => __( '<a href="http://www.w3schools.com/css/default.asp" TARGET="_blank"><div class="sonar-help" title="Help with CSS"></div></a>
					This input area is one of the most important options in sonar for customizing your site.
					Code entered into this box is included right before the &lt;/HEAD&gt; tag on each page of your site. The most important
					use for this area is to enter custom CSS rules to control the look of your site. <b>!Do Not Use</b> &lt;style&gt; tags.
					If you need to style something for Internet Explorer, simply add <code>#ie6</code>, <code>#ie7</code>, or <code>#ie8</code>
					before the selector your styling. ( eg. <code>#ie7 #site-title { margin-top: 0px;}</code> )','sonar'),
			'id' => 'sonar_header_css',
			'type' => 'textarea'),
	
	array("type" => "close"),
	
	// ************************************  Google Analytics  ************************************
	array("name" => __('<font size=4 color=#464646>Google Analytics</font>','sonar'),
			"type" => "section"),

	array("name" => __('<font size=2 color=#464646>Google Analytics Tracking Code</font>','sonar'),
			"type" => "section-desc"),
			
	array("type" => "open"),
	
	array( "name" => __( 'Google Analytics','sonar'),
			"desc" => __( '<font color=#444>Note:</font> the Google Analytics script now goes in the &lt;head&gt; element to better support the new asynchronous Google Analytics script.
						Please make sure you update your script to use the new asynchronous script from Google Analytics. <b>!Do Not Use</b> &lt;script&gt; tags.','sonar'),
			'id' => 'sonar_google_analytics',
			'type' => 'textarea'),
	
	array("type" => "close"),
	
);

function sonar_settings_page() {

   global $themename, $shortname, $version, $sonar_options, $option_group, $option_name;
?>

	<div class="wrap">
		<div class="options_wrap">
			<?php screen_icon(); ?><h2><?php echo $themename; ?> <?php _e('Theme Options','sonar'); ?></h2>
			<p class="top-notice"><?php _e('Customize the look of your Theme with these settings. ','sonar'); ?></p>
			<?php if ( isset ( $_POST['reset'] ) ): ?>
			<?php // Delete Settings

			global $wpdb, $themename, $shortname, $version, $sonar_options, $option_group, $option_name;

			delete_option('sonar_theme_options');

			wp_cache_flush(); ?>

			<div class="updated fade"><p><strong><?php _e( $themename. ' options reset.' ); ?></strong></p></div>
			<?php elseif ( isset ( $_REQUEST['updated'] ) ): ?>
			<div class="updated fade"><p><strong><?php _e( $themename. ' options saved.' ); ?></strong></p></div>
			<?php endif; ?>

			<form method="post" action="options.php">
				<?php settings_fields( $option_group ); ?>
				<?php $options = get_option( $option_name ); ?>
				<?php foreach ($sonar_options as $value) {
					if ( isset($value['id']) ) { $valueid = $value['id'];}
					switch ( $value['type'] ) {
						case "section": ?>

						<div class="section_wrap">
							<h3 class="section_title"><?php echo $value['name']; ?>
								<?php break;
								case "section-desc": ?>
								<span><?php echo $value['name']; ?></span>
							</h3>
							<div class="section_body">
								<?php
								break;

								case 'text':    // Text Box
								?>
								<div class="options_input options_text">
									<div class="options_desc"><?php echo $value['desc']; ?></div>
									<span class="labels"><label for="<?php echo $option_name.'['.$valueid.']'; ?>"><?php echo $value['name']; ?></label></span>
									<input name="<?php echo $option_name.'['.$valueid.']'; ?>" id="<?php echo $option_name.'['.$valueid.']'; ?>" type="<?php echo $value['type']; ?>" value="<?php if ( isset( $options[$valueid]) ){ esc_attr_e( stripslashes($options[$valueid])); } else { esc_attr_e( stripslashes($value['std'])); } ?>" />
								</div>
								<?php
								break;

								case 'ctext':    // Color Picker  
								?>
								<div class="options_input options_text">
									<div class="options_desc"><?php echo $value['desc']; ?></div>
									<span class="labels"><label for="<?php echo $option_name.'['.$valueid.']'; ?>"><?php echo $value['name']; ?></label></span>
									<input class="color {hash:true}" name="<?php echo $option_name.'['.$valueid.']'; ?>" id="<?php echo $option_name.'['.$valueid.']'; ?>" type="<?php echo $value['type']; ?>" value="<?php if ( isset( $options[$valueid]) ){ esc_attr_e($options[$valueid]); } else { esc_attr_e($value['std']); } ?>" />
								</div>
								<?php
								break;

								case 'textarea':	// Textarea
								?>
								<div class="options_input options_textarea">
									<div class="textarea_desc"><?php echo $value['desc']; ?></div>
									<span class="labels"><label for="<?php echo $option_name.'['.$valueid.']'; ?>"><?php echo $value['name']; ?></label></span>
									<textarea name="<?php echo $option_name.'['.$valueid.']'; ?>" type="<?php echo $option_name.'['.$valueid.']'; ?>" cols="" rows=""><?php if ( isset( $options[$valueid]) ){ esc_attr_e( stripslashes($options[$valueid])); }?></textarea>
								</div>
								<?php
								break;

								case 'select':		// Select Drop downs
								?>
								<div class="options_input options_select">
									<div class="options_desc"><?php echo $value['desc']; ?></div>
									<span class="labels"><label for="<?php echo $option_name.'['.$valueid.']'; ?>"><?php echo $value['name']; ?></label></span>
									<select name="<?php echo $option_name.'['.$valueid.']'; ?>" id="<?php echo $option_name.'['.$valueid.']'; ?>">
						
									<?php foreach ($value['value'] as $option) { ?>
										<option<?php if ($options[$valueid] == $option) { echo ' selected="selected"'; }?>><?php echo $option; ?></option>
									<?php } ?>
									</select>
								</div>
								<?php
								break;

								case "radio":		// Radio Buttons 
								?>

								<div class="options_input options_select">
									<div class="options_desc"><?php echo $value['desc']; ?></div>
									<span class="labels"><label for="<?php echo $option_name.'['.$valueid.']'; ?>"><?php echo $value['name']; ?></label></span>
									<?php foreach ($value['options'] as $key=>$option) {

										$radio_setting = $options[$valueid];
										if($radio_setting != ''){
											if ($key == $options[$valueid] ) {
												$checked = "checked=\"checked\"";
											} else {
												$checked = "";
											}
										}else{
											if($key == $value['std']){
												$checked = "checked=\"checked\"";
											}else{
												$checked = "";
											}
										}?>
										<input type="radio" id="<?php echo $option_name.'['.$valueid.']'; ?>" name="<?php echo $option_name.'['.$valueid.']'; ?>" value="<?php echo $key; ?>" <?php echo $checked; ?> /><?php echo $option; ?><br />
									<?php } ?>
								</div>

								<?php
								break;

								case "checkbox":		// Check Boxes
								?>
								<div class="options_input options_checkbox">
									<div class="options_desc"><?php echo $value['desc']; ?></div>
									<?php if( isset( $options[$valueid] ) ){ $checked = "checked=\"checked\""; }else{ $checked = "";} ?>
									<input type="checkbox" name="<?php echo $option_name.'['.$valueid.']'; ?>" id="<?php echo $option_name.'['.$valueid.']'; ?>" value="true" <?php echo $checked; ?> /> 
									<label for="<?php echo $option_name.'['.$valueid.']'; ?>"><?php echo $value['name']; ?></label>
								</div>

								<?php
								break;

								case "close":
								?>
							</div><!--#section_body-->
						</div><!--#section_wrap-->
						<?php
						break;
					}
				}?>
				<div class="info-box">
					<div style=" height:40px; padding:5px;">
						<span class="submit">
							<input class="button button-primary" type="submit" name="save" value="<?php _e('Save All Changes', 'sonar') ?>" />
						</span>
					</div>
			</form>
					<?php // sonar support Forum   ?>
					<div class="support-box" style="height: 85px;">
						<form action="http://wp-ultra.com/forum/" TARGET="_blank" method="post">
							<input class="button" style="background: #1B8018; border-color:#145E12; color:#FFF; font-weight: bold;text-shadow: rgba(0, 0, 0, 0.3) 0 -1px 0;
							"type="submit" name="forum" value="Support Forum" />
						</form>
						<p style="color: #777; margin-top: 5px;">Need Help? Got a Suggestion? Don't be shy... Let me help you.<p>
					</div>
					
					<?php // Reset sonar Options   ?>
					<div class="reset-box">
						<form method="post" action="" onSubmit="return confirm('Are you sure you want to reset all sonar settings?');">
							<span class="button-right" class="submit">
								<input class="button" style="background:#E41B17; border-color:red; color:#FFF; font-weight: bold;text-shadow: rgba(0, 0, 0, 0.3) 0 -1px 0;
								"type="submit" name="reset" value="<?php _e('Reset / Delete Settings', 'sonar') ?>" />
								<input type="hidden" name="action" value="reset" />
								<span><?php _e('<font color#222><b>Caution:</b></font> All entries will be deleted from database. Press when starting afresh or completely removing the theme.','sonar') ?></span>
							</span>
						</form>
					</div>
					
					<?php // sonar Donate Button   ?>
					<div class="donate-box">
						<form action="https://www.paypal.com/cgi-bin/webscr" TARGET="_blank" method="post">
							<input type="hidden" name="cmd" value="_s-xclick">
							<input type="hidden" name="hosted_button_id" value="63CVZ2AP6V3ZS">
							<input type="image" src="https://www.paypalobjects.com/WEBSCR-640-20110429-1/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
							<img alt="" border="0" src="https://www.paypalobjects.com/WEBSCR-640-20110429-1/en_US/i/scr/pixel.gif" width="1" height="1">
						</form>
						<p style="color: #777; margin-top: -5px;">Like the Theme? Please consider buying me a cup of coffee...<p>
					</div>
				</div><!--#options-wrap-->
		</div>
	</div>
<?php } 

	// validates the theme's options upon submission.
	function sonar_theme_options_validate( $input ) {
		global $sonar_options;
		foreach ( $sonar_options as $value ) {
			switch ( $value['type'] ) {
				case 'select':
					$input[$value['id']] = wp_filter_nohtml_kses( $input[$value['id']] );
					break;
				case 'ctext':
					$input[$value['id']] = wp_filter_nohtml_kses( $input[$value['id']] );
					break;
				case 'text':
					$input[$value['id']] = wp_filter_post_kses( $input[$value['id']] );
					break;
				case 'textarea':
					$input[$value['id']] = wp_filter_post_kses( $input[$value['id']] );
					break;
			}
		}
		return $input;
	} 
?>